package com.example.tdl.web;

import com.example.tdl.domain.dto.CommFeedback;
import com.example.tdl.domain.vo.*;
import com.example.tdl.service.AlarmLogService;
import com.example.tdl.service.CircuitService;

import com.google.gson.Gson;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/homePage")
public class HomePageController {
    private Logger logger = LoggerFactory.getLogger(HomePageController.class);

    Gson gson = new Gson();

    CommFeedback fb = new CommFeedback();

    @Autowired
    private CircuitService circuitService;

    @Autowired
    private AlarmLogService alarmLogServcie;

    //获取当天所有的设备数据
    @ApiOperation(value = "获取所有的运输数据",notes = "获取运输设备数据：" +
            "sum:总数量" +
            "onRoute:在途数量" +
            "complted:已完成数量" +
            "alarmed: 报警数量" +
            "routeVoList: " +
                "transportationNo:线路编号（R+TyyyyMMdd+运输方式+四位随机数）"+
                "routeName:路由名称（出发地-启运地）"+
                "startLongitude:启运经度"+
                "startLatitude:启运纬度"+
                "startCity:启运市"+
                "startTime:开始时间"+
                "endLongitude:目的经度"+
                "endLatitude:目的纬度"+
                "endCity:目的市"+
                "endTime:结束时间"+
                "transport:运输方式（T铁路，G汽运，H海运，K空运，D快递）"+
                "boxNo:箱单号" +
                "containerNo:集装箱号/车牌号" +
                "deliveryAddress:交付地点" +
                "transportationType:运输类型" +
                "circuitState:线路状态"+
                "remark:备注" +
            "alarmLogVoList :"+
                "routeName:线路名称"+
                "description:报警描述" +
                "data:数据"+
                "alarmTime:报警时间")
    @PostMapping("/getAll")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getAll(@RequestBody Integer time){
        //获取数量
        HomePageDataVo dataVo = new HomePageDataVo();
        //获取所有的线路数量
        Integer sum = circuitService.getCount(time);
        dataVo.setSum(sum);//总数量
        Integer onRoute = circuitService.getOnRoute(time);
        dataVo.setOnRoute(onRoute);//在途数量
        //获取延误数量
        Integer delay = circuitService.getDelayCount(System.currentTimeMillis());
        dataVo.setDelay(delay);
        //获取已经完成的数量
        Integer alarmed = alarmLogServcie.getCount(time);
        dataVo.setAlarmed(alarmed);//报警数量
        //获取颠簸数量
        Integer bump = alarmLogServcie.getBumpCount(time);
        dataVo.setBump(bump);
        //获取所有的报警
        // 获取所有的路线数量
        List<AlarmLogVo> alarmLogVos = new ArrayList<>();
        dataVo.setAlarmLogVoList(alarmLogVos);//报警列表


        return gson.toJson(dataVo);
    }
}
